@@ -21,6 +21,7 @@ has 'verbose_stats'               => ( is => 'rw', isa => 'Bool', default  => 0
 has 'translation_table'           => ( is => 'rw', isa => 'Int',  default  => 11 );
 has 'group_limit'                 => ( is => 'rw', isa => 'Num',  default  => 50000 );
 has 'core_definition'             => ( is => 'ro', isa => 'Num',  default  => 1.0 );
+has 'verbose'                     => ( is => 'rw', isa => 'Bool', default  => 0 );
 
 # Overload Role
 has '_memory_required_in_mb' => ( is => 'ro', isa => 'Int', lazy => 1, builder => '_build__memory_required_in_mb' );
@@ -100,6 +101,9 @@ sub _command_to_run {
 
     my $verbose_stats_flag = '';
     $verbose_stats_flag = '--verbose_stats' if ( defined($self->verbose_stats) && $self->verbose_stats == 1 );
+	
+    my $verbose_flag = '';
+    $verbose_flag = '-v' if ( defined($self->verbose) && $self->verbose == 1 );
     
     return join(
         " ",
@@ -117,6 +121,7 @@ sub _command_to_run {
             $dont_create_rplots_flag,
             $dont_split_groups_flag,
             $verbose_stats_flag,
+			$verbose_flag,
             '-j', $self->job_runner,
             '--processors', $self->cpus,
             '--group_limit', $self->group_limit,
@@ -159,7 +164,7 @@ Bio::Roary::External::PostAnalysis - Perform the post analysis
 
 =head1 VERSION
 
-version 2.1.1
+version 2.1.2
 
 =head1 SYNOPSIS
 
